# Mouth

Body service that handles outgoing communications like emails and sms messages.

This code comes without documentation as it's not meant to be used by anyone
outside of Ouroboros Coding Inc. Please see LICENSE for further information.
